======================
Advanced How-to Guides
======================

.. toctree::
    :maxdepth: 1

    setup-linux
    setup-mac
    setup-win
    documentation
    add-jupyter-kernel
    win-open-ssh
